@@ -1,6 +1,6 @@
 #!/bin/bash
 
-source "helpers.sh"
+source "test-helpers.sh"
 
 if [ "$1" == "" ]
 then
